@@ -10,8 +10,9 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+from unittest import mock
+
 import ddt
-import mock
 
 from stestr import config_file
 from stestr.tests import base
@@ -60,10 +61,11 @@ class TestTestrConf(base.TestCase):
         mock_TestProcessorFixture.assert_called_once_with(
             None, command, "--list", "--load-list $IDFILE",
             mock_get_repo_open.return_value, black_regex=None,
-            blacklist_file=None, concurrency=0,
+            exclude_regex=None,
+            blacklist_file=None, exclude_list=None, concurrency=0,
             group_callback=expected_group_callback,
             test_filters=None, randomize=False, serial=False,
-            whitelist_file=None, worker_path=None)
+            whitelist_file=None, include_list=None, worker_path=None)
 
     @mock.patch.object(config_file, 'sys')
     def _check_get_run_command_exception(self, mock_sys, platform='win32',
