@@ -21,8 +21,6 @@ import subprocess
 import tempfile
 
 import fixtures
-import six
-from six import StringIO
 import subunit as subunit_lib
 import testtools
 
@@ -46,15 +44,17 @@ class TestReturnCodes(base.TestCase):
         self.failing_file = os.path.join(self.test_dir, 'test_failing.py')
         self.init_file = os.path.join(self.test_dir, '__init__.py')
         self.setup_py = os.path.join(self.directory, 'setup.py')
+        self.user_config = os.path.join(self.directory, 'stestr.yaml')
         shutil.copy('stestr/tests/files/testr-conf', self.testr_conf_file)
         shutil.copy('stestr/tests/files/passing-tests', self.passing_file)
         shutil.copy('stestr/tests/files/failing-tests', self.failing_file)
         shutil.copy('setup.py', self.setup_py)
         shutil.copy('stestr/tests/files/setup.cfg', self.setup_cfg_file)
         shutil.copy('stestr/tests/files/__init__.py', self.init_file)
+        shutil.copy('stestr/tests/files/stestr.yaml', self.user_config)
 
-        self.stdout = StringIO()
-        self.stderr = StringIO()
+        self.stdout = io.StringIO()
+        self.stderr = io.StringIO()
         # Change directory, run wrapper and check result
         self.addCleanup(os.chdir, os.path.abspath(os.curdir))
         os.chdir(self.directory)
@@ -93,7 +93,7 @@ class TestReturnCodes(base.TestCase):
         if not subunit:
             self.assertEqual(
                 p.returncode, expected,
-                "Stdout: %s; Stderr: %s" % (out, err))
+                "Stdout: {}; Stderr: {}".format(out, err))
             return (out, err)
         else:
             self.assertEqual(p.returncode, expected,
@@ -141,6 +141,14 @@ class TestReturnCodes(base.TestCase):
         cmd = 'stestr run --blacklist-file %s' % path
         self.assertRunExit(cmd, 0)
 
+    def test_parallel_exclusion_list(self):
+        fd, path = tempfile.mkstemp()
+        self.addCleanup(os.remove, path)
+        with os.fdopen(fd, 'w') as exclusion_list:
+            exclusion_list.write('fail')
+        cmd = 'stestr run --exclude-list %s' % path
+        self.assertRunExit(cmd, 0)
+
     def test_parallel_whitelist(self):
         fd, path = tempfile.mkstemp()
         self.addCleanup(os.remove, path)
@@ -149,6 +157,14 @@ class TestReturnCodes(base.TestCase):
         cmd = 'stestr run --whitelist-file %s' % path
         self.assertRunExit(cmd, 0)
 
+    def test_parallel_inclusion_list(self):
+        fd, path = tempfile.mkstemp()
+        self.addCleanup(os.remove, path)
+        with os.fdopen(fd, 'w') as inclusion_list:
+            inclusion_list.write('passing')
+        cmd = 'stestr run --include-list %s' % path
+        self.assertRunExit(cmd, 0)
+
     def test_serial_passing(self):
         self.assertRunExit('stestr run --serial passing', 0)
 
@@ -163,6 +179,14 @@ class TestReturnCodes(base.TestCase):
         cmd = 'stestr run --serial --blacklist-file %s' % path
         self.assertRunExit(cmd, 0)
 
+    def test_serial_exclusion_list(self):
+        fd, path = tempfile.mkstemp()
+        self.addCleanup(os.remove, path)
+        with os.fdopen(fd, 'w') as exclusion_list:
+            exclusion_list.write('fail')
+        cmd = 'stestr run --serial --exclude-list %s' % path
+        self.assertRunExit(cmd, 0)
+
     def test_serial_whitelist(self):
         fd, path = tempfile.mkstemp()
         self.addCleanup(os.remove, path)
@@ -171,13 +195,29 @@ class TestReturnCodes(base.TestCase):
         cmd = 'stestr run --serial --whitelist-file %s' % path
         self.assertRunExit(cmd, 0)
 
+    def test_serial_inclusion_list(self):
+        fd, path = tempfile.mkstemp()
+        self.addCleanup(os.remove, path)
+        with os.fdopen(fd, 'w') as inclusion_list:
+            inclusion_list.write('passing')
+        cmd = 'stestr run --serial --include-list %s' % path
+        self.assertRunExit(cmd, 0)
+
     def test_serial_subunit_passing(self):
-        self.assertRunExit('stestr run --subunit passing', 0,
-                           subunit=True)
+        self.assertRunExit('stestr --user-config stestr.yaml run --subunit '
+                           '--serial passing', 0, subunit=True)
+
+    def test_serial_subunit_failing(self):
+        self.assertRunExit('stestr --user-config stestr.yaml run --subunit '
+                           '--serial failing', 0, subunit=True)
 
     def test_parallel_subunit_passing(self):
-        self.assertRunExit('stestr run --subunit passing', 0,
-                           subunit=True)
+        self.assertRunExit('stestr --user-config stestr.yaml run --subunit '
+                           'passing', 0, subunit=True)
+
+    def test_parallel_subunit_failing(self):
+        self.assertRunExit('stestr --user-config stestr.yaml run --subunit '
+                           'failing', 0, subunit=True)
 
     def test_slowest_passing(self):
         self.assertRunExit('stestr run --slowest passing', 0)
@@ -189,8 +229,37 @@ class TestReturnCodes(base.TestCase):
         self.assertRunExit('stestr run --until-failure', 1)
 
     def test_until_failure_with_subunit_fails(self):
-        self.assertRunExit('stestr run --until-failure --subunit', 1,
-                           subunit=True)
+        self.assertRunExit('stestr --user-config stestr.yaml run '
+                           '--until-failure --subunit', 1, subunit=True)
+
+    def test_with_parallel_class(self):
+        # NOTE(masayukig): Ideally, it's better to figure out the
+        # difference between with --parallel-class and without
+        # --parallel-class. However, it's difficult to make such a
+        # test from a command line based test.
+        self.assertRunExit('stestr --parallel-class run passing', 0)
+
+    def test_no_repo_dir(self):
+        stestr_repo_dir = os.path.join(self.directory, '.stestr')
+        shutil.rmtree(stestr_repo_dir, ignore_errors=True)
+        # We can use stestr run even if there's no repo directory.
+        self.assertRunExit('stestr run passing', 0)
+
+    def test_empty_repo_dir(self):
+        stestr_repo_dir = os.path.join(self.directory, '.stestr')
+        shutil.rmtree(stestr_repo_dir, ignore_errors=True)
+        os.mkdir(stestr_repo_dir)
+        # We can initialize an empty repo directory.
+        self.assertRunExit('stestr run passing', 0)
+
+    def test_non_empty_repo_dir(self):
+        stestr_repo_dir = os.path.join(self.directory, '.stestr')
+        shutil.rmtree(stestr_repo_dir, ignore_errors=True)
+        os.mkdir(stestr_repo_dir)
+        with open(os.path.join(stestr_repo_dir, 'foo'), 'wt') as stream:
+            stream.write('1\n')
+        # We can't initialize a non-empty repo directory.
+        self.assertRunExit('stestr run passing', 1)
 
     def test_list(self):
         self.assertRunExit('stestr list', 0)
@@ -206,16 +275,16 @@ class TestReturnCodes(base.TestCase):
         self.assertRunExit('stestr run passing', 0)
         stdout = self._get_cmd_stdout(
             'stestr last --no-subunit-trace')
-        stdout = six.text_type(stdout[0])
+        stdout = str(stdout[0])
         test_count_split = stdout.split(' ')
         test_count = test_count_split[1]
         test_count = int(test_count)
-        id_regex = re.compile('\(id=(.*?)\)')
+        id_regex = re.compile(r'\(id=(.*?)\)')
         test_id = id_regex.search(stdout).group(0)
         self.assertRunExit('stestr run --combine passing', 0)
         combine_stdout = self._get_cmd_stdout(
             'stestr last --no-subunit-trace')[0]
-        combine_stdout = six.text_type(combine_stdout)
+        combine_stdout = str(combine_stdout)
         combine_test_count_split = combine_stdout.split(' ')
         combine_test_count = combine_test_count_split[1]
         combine_test_count = int(combine_test_count)
@@ -232,21 +301,39 @@ class TestReturnCodes(base.TestCase):
             'stestr last --subunit')[0]
         self.assertRunExit('stestr load', 0, stdin=stream)
 
+    def test_load_force_init(self):
+        self.assertRunExit('stestr run passing', 0)
+        stream = self._get_cmd_stdout(
+            'stestr last --subunit')[0]
+        # NOTE: --force-init should work here because there is an properly
+        # initialized repository.
+        self.assertRunExit('stestr load --force-init', 0, stdin=stream)
+
+    def test_load_force_init_invalid(self):
+        self.assertRunExit('stestr run passing', 0)
+        stream = self._get_cmd_stdout(
+            'stestr last --subunit')[0]
+        os.remove(os.path.join(self.directory, '.stestr', 'format'))
+        # NOTE: --force-init should fail here because there is an invalid
+        # repository.
+        self.assertRunExit('stestr load --force-init', 1, stdin=stream)
+
     def test_load_from_stdin_quiet(self):
-        out, err = self.assertRunExit('stestr -q run passing', 0)
+        out, err = self.assertRunExit('stestr --user-config stestr.yaml -q '
+                                      'run passing', 0)
         self.assertEqual(out.decode('utf-8'), '')
         # FIXME(masayukig): We get some warnings when we run a coverage job.
         # So, just ignore 'err' here.
-        stream = self._get_cmd_stdout(
-            'stestr last --subunit')[0]
-        out, err = self.assertRunExit('stestr -q load', 0, stdin=stream)
+        stream = self._get_cmd_stdout('stestr last --subunit')[0]
+        out, err = self.assertRunExit('stestr --user-config stestr.yaml -q '
+                                      'load', 0, stdin=stream)
         self.assertEqual(out.decode('utf-8'), '')
         self.assertEqual(err.decode('utf-8'), '')
 
     def test_no_subunit_trace_force_subunit_trace(self):
         out, err = self.assertRunExit(
             'stestr run --no-subunit-trace --force-subunit-trace passing', 0)
-        out = six.text_type(out)
+        out = str(out)
         self.assertNotIn('PASSED (id=0)', out)
         self.assertIn('Totals', out)
         self.assertIn('Worker Balance', out)
@@ -275,6 +362,19 @@ class TestReturnCodes(base.TestCase):
         self.assertEqual(0, run.run_command(filters=['passing'], serial=True,
                                             stdout=stdout.stream))
 
+    def test_str_concurrency_passing_from_func(self):
+        stdout = fixtures.StringStream('stdout')
+        self.useFixture(stdout)
+        self.assertEqual(0, run.run_command(filters=['passing'],
+                                            concurrency='1',
+                                            stdout=stdout.stream))
+
+    def test_str_concurrency_fails_from_func(self):
+        stdout = fixtures.StringStream('stdout')
+        self.useFixture(stdout)
+        self.assertEqual(1, run.run_command(concurrency='1',
+                                            stdout=stdout.stream))
+
     def test_serial_fails_from_func(self):
         stdout = fixtures.StringStream('stdout')
         self.useFixture(stdout)
